@@ -229,6 +229,10 @@ class CategorizationObject:
             "income_source_uid" : None,
             "is_loan_received" : None,
             "is_loan_requested": None,
+            "collective_subcategory_uid" : None,
+            "collective_description" : None,
+            "collective_is_essential" : None,
+            "collective_is_membership" : None
 			}
 
     def get(self):
